==> com.liferay.wiki.api-3.0.3-sources.jar: com/liferay/wiki/constants/WikiWebKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.wiki.constants;

/**
 * @author Iván Zaera
 */
public class WikiWebKeys {

	public static final String DL_MIME_TYPE_DISPLAY_CONTEXT =
		"DL_MIME_TYPE_DISPLAY_CONTEXT";

	public static final String SHOW_SIDEBAR_HEADER = "SHOW_SIDEBAR_HEADER";

	public static final String WIKI_ENGINE_RENDERER = "WIKI_ENGINE_RENDERER";

	public static final String WIKI_IMPORTER_TRACKER = "WIKI_IMPORTER_TRACKER";

	public static final String WIKI_NODE = "WIKI_NODE";

	public static final String WIKI_NODE_ID = "WIKI_NODE_ID";

	public static final String WIKI_NODES = "WIKI_NODES";

	public static final String WIKI_PAGE = "WIKI_PAGE";

	public static final String WIKI_PAGE_TITLE_VALIDATOR =
		"WIKI_PAGE_TITLE_VALIDATOR";

	public static final String WIKI_PAGES = "WIKI_PAGES";

	public static final String WIKI_PORTLET_TOOLBAR_CONTRIBUTOR =
		"WIKI_PORTLET_TOOLBAR_CONTRIBUTOR";

	public static final String WIKI_TREE_WALKER_DEPTH =
		"WIKI_TREE_WALKER_DEPTH";

	public static final String WIKI_TREE_WALKER_PAGE = "WIKI_TREE_WALKER_PAGE";

	public static final String WIKI_TREE_WALKER_PARENT =
		"WIKI_TREE_WALKER_PARENT";

}

==> com.liferay.wiki.api-12.0.0-sources.jar: com/liferay/wiki/constants/WikiWebKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.wiki.constants;

/**
 * @author Iván Zaera
 */
public class WikiWebKeys {

	public static final String SHOW_SIDEBAR_HEADER = "SHOW_SIDEBAR_HEADER";

	public static final String WIKI_ENGINE_RENDERER = "WIKI_ENGINE_RENDERER";

	public static final String WIKI_IMPORTER_REGISTRY =
		"WIKI_IMPORTER_REGISTRY";

	public static final String WIKI_NODE = "WIKI_NODE";

	public static final String WIKI_NODE_ID = "WIKI_NODE_ID";

	public static final String WIKI_NODES = "WIKI_NODES";

	public static final String WIKI_PAGE = "WIKI_PAGE";

	public static final String WIKI_PAGE_TITLE_VALIDATOR =
		"WIKI_PAGE_TITLE_VALIDATOR";

	public static final String WIKI_PAGES = "WIKI_PAGES";

	public static final String WIKI_PORTLET_TOOLBAR_CONTRIBUTOR =
		"WIKI_PORTLET_TOOLBAR_CONTRIBUTOR";

	public static final String WIKI_TREE_WALKER_DEPTH =
		"WIKI_TREE_WALKER_DEPTH";

	public static final String WIKI_TREE_WALKER_PAGE = "WIKI_TREE_WALKER_PAGE";

	public static final String WIKI_TREE_WALKER_PARENT =
		"WIKI_TREE_WALKER_PARENT";

}
